@@ -1,5 +1,6 @@
 import httpx
-from httpx import ConnectError, ConnectTimeout, ProxyError, ReadTimeout
+from httpx import Request
+from httpx import ConnectError, ConnectTimeout, ProxyError, ReadTimeout, ReadError, UnsupportedProtocol
 from fake_useragent import UserAgent
 from scan.response import Response
 from scan.common import logger
@@ -54,42 +55,72 @@ class Downloader(object):
             await logger.info(f'{response.status_code}  {request.url}')
 
     async def request(self, url, params=None, headers=None, cookies=None, auth=None, proxies=None, allow_redirects=True,
-                      content=None, data=None, files=None, json=None, timeout=30, cycle=3):
+                      content=None, data=None, files=None, json=None, stream=False, timeout=30, cycle=3):
         if data or json or content:
             method = 'POST'
         else:
             method = 'GET'
         if not headers:
             headers = await self.gen_headers()
+        response = Response()
         for _ in range(cycle):
             try:
-                if not proxies:
+                if stream:
+                    request = Request(method=method, url=url, headers=headers, cookies=cookies, content=content,
+                                      data=data, files=files, json=json)
+                    if proxies:
+                        client = httpx.AsyncClient(proxies=proxies, event_hooks={'response': [self.log_response]})
+                        resp = await client.send(request, stream=True)
+                        response.response = resp
+                        response.ok = True
+                        response.client = client  # need aclose
+                    else:
+                        if not self.client:
+                            self.client = httpx.AsyncClient(event_hooks={'response': [self.log_response]})
+                        resp = await self.client.send(request, stream=True)
+                        response.response = resp
+                        response.ok = True
+                elif not proxies:
                     if not self.client:
                         self.client = httpx.AsyncClient(event_hooks={'response': [self.log_response]})
                     resp = await self.client.request(
                         method=method, url=url, content=content, data=data, files=files, json=json, params=params,
-                        headers=headers, cookies=cookies, auth=auth, allow_redirects=allow_redirects, timeout=timeout
+                        headers=headers, cookies=cookies, auth=auth, follow_redirects=allow_redirects, timeout=timeout
                     )
-                    response = Response(resp)
+                    response.response = resp
+                    response.ok = True
                 else:
                     async with httpx.AsyncClient(proxies=proxies, event_hooks={'response': [self.log_response]}) as client:
                         resp = await client.request(
                             method=method, url=url, content=content, data=data, files=files, json=json, params=params,
-                            headers=headers, cookies=cookies, auth=auth, allow_redirects=allow_redirects,
+                            headers=headers, cookies=cookies, auth=auth, follow_redirects=allow_redirects,
                             timeout=timeout
                         )
-                        response = Response(resp)
+                        response.response = resp
+                        response.ok = True
                 return response
             except ConnectError as e:
+                response.message = 'ConnectError'
                 await logger.error(f'Failed to request {url}  ConnectError:{e}')
             except ConnectTimeout as e:
+                response.message = 'ConnectTimeout'
                 await logger.error(f'Failed to request {url}  ConnectTimeout:{e}')
             except ProxyError as e:
+                response.message = 'ProxyError'
                 await logger.error(f'Failed to request {url}  ProxyError:{e}')
             except ReadTimeout as e:
+                response.message = 'ReadTimeout'
                 await logger.error(f'Failed to request {url}  ReadTimeout:{e}')
+            except ReadError as e:
+                response.message = 'ReadError'
+                await logger.error(f'Failed to request {url}  ReadError:{e}')
+            except UnsupportedProtocol as e:
+                response.message = 'UnsupportedProtocol'
+                await logger.error(f'Failed to request {url}  UnsupportedProtocol:{e}')
             except Exception as e:
+                response.message = e
                 await logger.error(f'Failed to request {url}  {e}')
+        return response
 
 
 
