@@ -63,43 +63,87 @@ class Spider(object):
         :return:
         """
 
-    # async def on_success(self, redis_conn=None, spider_id=None, count=1):
-    #     """
-    #     处理成功计数
-    #     :param redis_conn:
-    #     :param spider_id: spider_name-local_ip-container_id
-    #     :param count:
-    #     :return:
-    #     """
-    #     if not redis_conn and not self.redis_conn:
-    #         await logger.error('没有redis连接信息，不能计数')
-    #         return
-    #     try:
-    #         # 10分钟一组
-    #         tick = date_to_char('m')[:-1] + '0'
-    #         # 如 test_spider-192.168.0.182-mac.local-202004261430
-    #         if spider_id:
-    #             count_key = spider_id + '-' + tick
-    #         else:
-    #             count_key = self.spider_id + '-' + tick
-    #         if redis_conn:
-    #             await redis_conn.incrby(count_key, count)
-    #         else:
-    #             await self.redis_conn.incrby(count_key, count)
-    #     except Exception as e:
-    #         await logger.error(f'处理成功回调异常:{spider_id} {e}')
-
-    async def on_success(self, mongo_db=None, spider_id=None, count=1):
+    async def on_success(self, msg, mongo_conn=None, collection=None, spider_name=None, desc=None, url=None,
+                         headers=None):
         """
-        处理成功计数
+        处理成功回调
+        """
+        if not self.mongo_db and not mongo_conn:
+            await logger.error('没有mongodb连接信息，不能保存日志')
+            return
+        if not collection:
+            collection = 'spider_success_logs'
+        try:
+            save_data = {
+                "ip": self.local_ip,
+                'spider_name': spider_name or self.spider_name,
+                'cid': self.container_id,
+                'url': url,
+                'headers': headers,
+                'datetime': str(datetime.datetime.now()),
+                'desc': desc,
+                'msg': msg
+            }
+            if mongo_conn:
+                await mongo_conn.get_collection(collection).insert_one(save_data)
+            else:
+                await self.mongo_db.get_collection(collection).insert_one(save_data)
+        except Exception as e:
+            await logger.error(f'处理成功回调异常:{spider_name}-{self.local_ip}-{self.container_id} {e}')
+
+    async def on_error(self, msg, mongo_conn=None, collection=None, spider_name=None, desc=None, url=None, headers=None):
+        """
+        处理失败日志记录
+        :param collection:
+        :param mongo_conn:
+        :param spider_name:
+        :param desc:
+        :param msg: traceback信息
+        :param url:
+        :param headers:
+        """
+        await logger.error(msg)
+        if not self.mongo_db and not mongo_conn:
+            await logger.error('没有mongodb连接信息，不能保存日志')
+            return
+        if not collection:
+            collection = 'spider_error_logs'
+        try:
+            save_data = {
+                "ip": self.local_ip,
+                'spider_name': spider_name or self.spider_name,
+                'cid': self.container_id,
+                'url': url,
+                'headers': headers,
+                'datetime': str(datetime.datetime.now()),
+                'desc': desc,
+                'msg': str(msg)
+            }
+            if mongo_conn:
+                await mongo_conn.get_collection(collection).insert_one(save_data)
+            else:
+                await self.mongo_db.get_collection(collection).insert_one(save_data)
+        except Exception as e:
+            await logger.error(f'处理失败回调异常:{spider_name}-{self.local_ip}-{self.container_id} {e}')
+
+    async def on_count(self, count_type,  mongo_db=None, collection=None, spider_id=None, count=1):
+        """
+        计数回调
+        :param count_type: 1 成功  0 失败
+        :param collection:
         :param mongo_db:
         :param spider_id: spider_name-local_ip-container_id
         :param count:
         :return:
         """
+        if count_type not in [1, 0]:
+            await logger.error('状态参数异常，不能计数')
+            return
         if not mongo_db and not self.mongo_db:
             await logger.error('没有mongodb连接信息，不能计数')
             return
+        if not collection:
+            collection = 'spider_statistics'
         try:
             # 10分钟一组
             tick = date_to_char('m')[:-1] + '0'
@@ -112,53 +156,23 @@ class Spider(object):
             if not mongo_db:
                 mongo_db = self.mongo_db
             _id = encrypt(count_key)
-            try:
-                db_data = await mongo_db.get_collection('spider_statistics').find_one({'_id': _id})
-                if db_data:
-                    await mongo_db.get_collection('spider_statistics').update_one(
-                        {'_id': count_key}, {'$inc': {'count': count}})
-                else:
-                    await mongo_db.get_collection('spider_statistics').insert_one(
-                        {'_id': count_key, 'sid': spider_id, 'date': tick, 'count': count})
-            except DuplicateKeyError:
-                await mongo_db.get_collection('spider_statistics').update_one(
-                    {'_id': count_key}, {'$inc': {'count': count}})
-        except Exception as e:
-            await logger.error(f'处理成功回调异常:{spider_id} {e}')
-
-
-
-    async def on_error(self, e, mongo_conn=None, spider_name=None, desc=None, url=None, headers=None):
-        """
-        处理失败日志记录
-        :param mongo_conn:
-        :param spider_name:
-        :param desc:
-        :param e: traceback信息
-        :param url:
-        :param headers:
-        """
-        await logger.error(e)
-        if not self.mongo_db and not mongo_conn:
-            await logger.error('没有mongodb连接信息，不能保存日志')
-            return
-        try:
-            save_data = {
-                "ip": self.local_ip,
-                'spider_name': spider_name or self.spider_name,
-                'cid': self.container_id,
-                'url': url,
-                'headers': headers,
-                'datetime': str(datetime.datetime.now()),
-                'desc': desc,
-                'e': str(e)
-            }
-            if mongo_conn:
-                await mongo_conn.get_collection('spider_error_logs').insert_one(save_data)
+            if count_type == 1:
+                count_type_key = 'suc_count'
             else:
-                await self.mongo_db.get_collection('spider_error_logs').insert_one(save_data)
+                count_type_key = 'fail_count'
+            try:
+                db_data = await mongo_db.get_collection(collection).find_one({'_id': _id})
+                if db_data:
+                    await mongo_db.get_collection(collection).update_one(
+                        {'_id': _id}, {'$inc': {count_type_key: count}})
+                else:
+                    await mongo_db.get_collection(collection).insert_one(
+                        {'_id': _id, 'sid': spider_id, 'date': tick, count_type_key: count})
+            except DuplicateKeyError:
+                await mongo_db.get_collection(collection).update_one(
+                    {'_id': _id}, {'$inc': {'count': count}})
         except Exception as e:
-            await logger.error(f'处理失败回调异常:{spider_name}-{self.local_ip}-{self.container_id} {e}')
+            await logger.error(f'处理成功计数回调异常:{spider_id} {e}')
 
     async def queue_task(self):
         """
